Documentation
¶
Index ¶
- Variables
- type Message
- func (*Message) Descriptor() ([]byte, []int)
- func (m *Message) GetChannel() string
- func (m *Message) GetCreated() int64
- func (m *Message) GetPayload() []byte
- func (m *Message) GetProtocol() string
- func (m *Message) GetPublisher() string
- func (m *Message) GetSubtopic() string
- func (m *Message) Marshal() (dAtA []byte, err error)
- func (m *Message) MarshalTo(dAtA []byte) (int, error)
- func (m *Message) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*Message) ProtoMessage()
- func (m *Message) Reset()
- func (m *Message) Size() (n int)
- func (m *Message) String() string
- func (m *Message) Unmarshal(dAtA []byte) error
- func (m *Message) XXX_DiscardUnknown()
- func (m *Message) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Message) XXX_Merge(src proto.Message)
- func (m *Message) XXX_Size() int
- func (m *Message) XXX_Unmarshal(b []byte) error
- type MessageHandler
- type PubSub
- type Publisher
- type Subscriber
Constants ¶
This section is empty.
Variables ¶
Functions ¶
This section is empty.
Types ¶
type Message ¶
type Message struct {
Channel string `protobuf:"bytes,1,opt,name=channel,proto3" json:"channel,omitempty"`
Subtopic string `protobuf:"bytes,2,opt,name=subtopic,proto3" json:"subtopic,omitempty"`
Publisher string `protobuf:"bytes,3,opt,name=publisher,proto3" json:"publisher,omitempty"`
Protocol string `protobuf:"bytes,4,opt,name=protocol,proto3" json:"protocol,omitempty"`
Payload []byte `protobuf:"bytes,5,opt,name=payload,proto3" json:"payload,omitempty"`
Created int64 `protobuf:"varint,6,opt,name=created,proto3" json:"created,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Message represents a message emitted by the Mainflux adapters layer.
func (*Message) Descriptor ¶
func (*Message) GetChannel ¶
func (*Message) GetCreated ¶
func (*Message) GetPayload ¶
func (*Message) GetProtocol ¶
func (*Message) GetPublisher ¶
func (*Message) GetSubtopic ¶
func (*Message) MarshalToSizedBuffer ¶
func (*Message) ProtoMessage ¶
func (*Message) ProtoMessage()
func (*Message) XXX_DiscardUnknown ¶
func (m *Message) XXX_DiscardUnknown()
func (*Message) XXX_Marshal ¶
func (*Message) XXX_Unmarshal ¶
type MessageHandler ¶
MessageHandler represents Message handler for Subscriber.
type PubSub ¶
type PubSub interface {
Publisher
Subscriber
}
PubSub represents aggregation interface for publisher and subscriber.
type Publisher ¶
type Publisher interface {
// Publishes message to the stream.
Publish(topic string, msg Message) error
}
Publisher specifies message publishing API.
type Subscriber ¶
type Subscriber interface {
// Subscribe subscribes to the message stream and consumes messages.
Subscribe(topic string, handler MessageHandler) error
// Unsubscribe unsubscribes from the message stream and
// stops consuming messages.
Unsubscribe(topic string) error
}
Subscriber specifies message subscription API.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package nats hold the implementation of the Publisher and PubSub interfaces for the NATS messaging system, the internal messaging broker of the Mainflux IoT platform.
|
Package nats hold the implementation of the Publisher and PubSub interfaces for the NATS messaging system, the internal messaging broker of the Mainflux IoT platform. |
Click to show internal directories.
Click to hide internal directories.